@@ -30,7 +30,10 @@ from ..usecases.distracted_driver_detection import DistractedDriverUseCase, Dist
 from ..usecases.emergency_vehicle_detection import EmergencyVehicleUseCase, EmergencyVehicleConfig
 from ..usecases.solar_panel import SolarPanelUseCase, SolarPanelConfig
 from ..usecases.chicken_pose_detection import ChickenPoseDetectionUseCase,ChickenPoseDetectionConfig
+from ..usecases.theft_detection import TheftDetectionUseCase,TheftDetectionConfig
+from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig, TrafficSignMonitoringUseCase
 from ..usecases.crop_weed_detection import CropWeedDetectionUseCase, CropWeedDetectionConfig
+from ..usecases.child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -58,7 +61,10 @@ __all__ = [
     'EmergencyVehicleUseCase',
     'ChickenPoseDetectionUseCase',
     'SolarPanelUseCase',
+    'TheftDetectionUseCase',
+    'TrafficSignMonitoringUseCase',
     'CropWeedDetectionUseCase',
+    'ChildMonitoringUseCase',
     'PeopleCountingConfig',
     'PotholeConfig',
     'BananaMonitoringConfig',
@@ -83,5 +89,8 @@ __all__ = [
     'EmergencyVehicleConfig',
     'ChickenPoseDetectionConfig',
     'SolarPanelConfig',
-    'CropWeedDetectionConfig'
+    'TheftDetectionConfig',
+    'TrafficSignMonitoringConfig',
+    'CropWeedDetectionConfig',
+    'ChildMonitoringConfig',
 ]
