@@ -405,10 +405,14 @@ class ConfigManager:
             "weld_defect_detection" : None,
             "banana_defect_detection" : None,
             "chicken_pose_detection" : None,
+            "traffic_sign_monitoring" : None,
+            "theft_detection" : None,
+
             "solar_panel": None,
             "crop_weed_detection": None,
             "emergency_vehicle_detection": None,
-            "price_tag_detection": None
+            "price_tag_detection": None,
+            "child_monitoring": None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -439,6 +443,22 @@ class ConfigManager:
         except ImportError:
             return None
         
+    def theft_detection_config_class(self):
+        """Get  theft detection class to avoid circular imports."""
+        try:
+            from ..usecases.theft_detection import TheftDetectionConfig
+            return TheftDetectionConfig
+        except ImportError:
+            return None
+        
+    def traffic_sign_monitoring_config_class(self):
+        """Get traffic sign monitoring class to avoid circular imports."""
+        try:
+            from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
+            return TrafficSignMonitoringConfig
+        except ImportError:
+            return None
+        
     def chicken_pose_detection_config_class(self):
         """Get Chicken pose monitoring class to avoid circular imports."""
         try:
@@ -575,6 +595,14 @@ class ConfigManager:
             return CropWeedDetectionConfig
         except ImportError:
             return None
+    
+    def child_monitoring_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.child_monitoring import ChildMonitoringConfig
+            return ChildMonitoringConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -823,6 +851,38 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "theft_detection":
+            # Import here to avoid circular import
+            from ..usecases.theft_detection import TheftDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = TheftDetectionConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
+        elif usecase == "traffic_sign_monitoring ":
+            # Import here to avoid circular import
+            from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = TrafficSignMonitoringConfig(
+                category=category or "traffic",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "vehicle_monitoring":
             # Import here to avoid circular import
             from ..usecases.vehicle_monitoring import VehicleMonitoringConfig
@@ -1030,6 +1090,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "child_monitoring":
+            # Import here to avoid circular import
+            from ..usecases.child_monitoring import ChildMonitoringConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = ChildMonitoringConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1184,6 +1260,18 @@ class ConfigManager:
             default_config = BananaMonitoringConfig()
             return default_config.to_dict()
         
+        elif usecase == "traffic_sign_monitoring":
+            # Import here to avoid circular import
+            from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
+            default_config = TrafficSignMonitoringConfig()
+            return default_config.to_dict()
+
+        elif usecase == "theft_detection":
+            # Import here to avoid circular import
+            from ..usecases.theft_detection import TheftDetectionConfig
+            default_config = TheftDetectionConfig()
+            return default_config.to_dict()
+        
         elif usecase == "weld_defect_detection":
             # Import here to avoid circular import
             from ..usecases.weld_defect_detection import WeldDefectConfig
@@ -1247,6 +1335,11 @@ class ConfigManager:
             from ..usecases.crop_weed_detection import CropWeedDetectionConfig
             default_config = CropWeedDetectionConfig()
             return default_config.to_dict()
+        elif usecase == "child_monitoring":
+            # Import here to avoid circular import
+            from ..usecases.child_monitoring import ChildMonitoringConfig
+            default_config = ChildMonitoringConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
