@@ -46,6 +46,8 @@ from .usecases import (
     UnderwaterPlasticUseCase,
     PedestrianDetectionUseCase,
     ChickenPoseDetectionUseCase,
+    TheftDetectionUseCase,
+    TrafficSignMonitoringUseCase,
 
     AgeDetectionUseCase,
     WeldDefectUseCase,
@@ -55,7 +57,8 @@ from .usecases import (
     DistractedDriverUseCase,
     EmergencyVehicleUseCase,
     SolarPanelUseCase,
-    CropWeedDetectionUseCase
+    CropWeedDetectionUseCase,
+    ChildMonitoringUseCase
 
 
 )
@@ -129,6 +132,8 @@ class PostProcessor:
 
         registry.register_use_case("traffic", "vehicle_monitoring", VehicleMonitoringUseCase)
         registry.register_use_case("traffic", "fruit_monitoring", BananaMonitoringUseCase)
+        registry.register_use_case("traffic", "theft_detection", TheftDetectionUseCase)
+        registry.register_use_case("traffic", "traffic_sign_monitoring", TrafficSignMonitoringUseCase)
         
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
         registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
@@ -145,6 +150,7 @@ class PostProcessor:
         registry.register_use_case("energy", "solar_panel", SolarPanelUseCase)
         registry.register_use_case("agriculture", "chicken_pose_detection", ChickenPoseDetectionUseCase)
         registry.register_use_case("agriculture", "crop_weed_detection", CropWeedDetectionUseCase)
+        registry.register_use_case("security", "child_monitoring", ChildMonitoringUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -243,6 +249,10 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, ChickenPoseDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, TheftDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, TrafficSignMonitoringUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FlareAnalysisUseCase):
                 result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
             elif isinstance(use_case,LicensePlateUseCase):
