@@ -32,7 +32,10 @@ from .distracted_driver_detection import DistractedDriverUseCase, DistractedDriv
 from .emergency_vehicle_detection import EmergencyVehicleUseCase, EmergencyVehicleConfig
 from .solar_panel import SolarPanelUseCase, SolarPanelConfig
 from .chicken_pose_detection import ChickenPoseDetectionConfig,ChickenPoseDetectionUseCase
+from .traffic_sign_monitoring import TrafficSignMonitoringConfig, TrafficSignMonitoringUseCase
+from .theft_detection import TheftDetectionConfig , TheftDetectionUseCase
 from .crop_weed_detection import CropWeedDetectionConfig, CropWeedDetectionUseCase
+from .child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
 
 
 __all__ = [
@@ -57,11 +60,14 @@ __all__ = [
     'AgeDetectionUseCase',
     'WeldDefectUseCase',
     'PriceTagUseCase',
+    'TheftDetectionUseCase',
+    'TrafficSignMonitoringUseCase',
     'DistractedDriverUseCase',
     'EmergencyVehicleUseCase',
     'SolarPanelUseCase',
     'ChickenPoseDetectionUseCase',
     'CropWeedDetectionUseCase',
+    'ChildMonitoringUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -85,6 +91,10 @@ __all__ = [
     'PriceTagConfig',
     'DistractedDriverConfig',
     'EmergencyVehicleConfig',
+    'TheftDetectionConfig',
+    'TrafficSignMonitoringConfig',
+    'SolarPanelConfig'
     'SolarPanelConfig',
-    'CropWeedDetectionConfig'
+    'CropWeedDetectionConfig',
+    'ChildMonitoringConfig'
 ]
\ No newline at end of file
